pub struct transferRegistrationCall {
pub _srcNamehash: FixedBytes<32>,
pub _dstNamehash: FixedBytes<32>,
pub _maxAmount: U256,
pub _duration: U256,
}Expand description
Transfers tokens between registrations for the caller.
Source must be expired or default. Emits TokensBound/BindCreated/
BindAmountIncreased/BindDurationExtended. Reverts on invalid duration,
invalid params for default dest, expired lock, unexpired source, or zero
amount/duration for new binds.
Function with signature transferRegistration(bytes32,bytes32,uint256,uint256) and selector 0x7a7b2c91.
function transferRegistration(bytes32 _srcNamehash, bytes32 _dstNamehash, uint256 _maxAmount, uint256 _duration) external;Fields
_srcNamehash: FixedBytes<32>_dstNamehash: FixedBytes<32>_maxAmount: U256_duration: U256Trait Implementations
Sourceimpl Clone for transferRegistrationCall
impl Clone for transferRegistrationCall
Sourcefn clone(&self) -> transferRegistrationCall
fn clone(&self) -> transferRegistrationCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for transferRegistrationCall
impl SolCall for transferRegistrationCall
Sourceconst SIGNATURE: &'static str = "transferRegistration(bytes32,bytes32,uint256,uint256)"
const SIGNATURE: &'static str = "transferRegistration(bytes32,bytes32,uint256,uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, FixedBytes<32>, Uint<256>, Uint<256>)
type Parameters<'a> = (FixedBytes<32>, FixedBytes<32>, Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<transferRegistrationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<transferRegistrationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = transferRegistrationReturn
type Return = transferRegistrationReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<transferRegistrationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<transferRegistrationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.