BlockId

Enum BlockId 

pub enum BlockId {
    Hash(RpcBlockHash),
    Number(BlockNumberOrTag),
}
Variants



Hash(RpcBlockHash)

A block hash and an optional bool that defines if it’s canonical



Number(BlockNumberOrTag)

A block number

Implementations

Source

impl BlockId

pub const fn as_block_hash(&self) -> Option<FixedBytes<32>>

Returns the block hash if it is BlockId::Hash

pub const fn as_u64(&self) -> Option<u64>

Returns the block number if it is BlockId::Number and not a tag

pub const fn is_latest(&self) -> bool

Returns true if this is BlockNumberOrTag::Latest

pub const fn is_pending(&self) -> bool

Returns true if this is BlockNumberOrTag::Pending

pub const fn is_safe(&self) -> bool

Returns true if this is BlockNumberOrTag::Safe

pub const fn is_finalized(&self) -> bool

Returns true if this is BlockNumberOrTag::Finalized

pub const fn is_earliest(&self) -> bool

Returns true if this is BlockNumberOrTag::Earliest

pub const fn is_number(&self) -> bool

Returns true if this is BlockNumberOrTag::Number

pub const fn is_hash(&self) -> bool

Returns true if this is BlockId::Hash

pub const fn pending() -> BlockId

Creates a new “pending” tag instance.

pub const fn latest() -> BlockId

Creates a new “latest” tag instance.

pub const fn earliest() -> BlockId

Creates a new “earliest” tag instance.

pub const fn finalized() -> BlockId

Creates a new “finalized” tag instance.

pub const fn safe() -> BlockId

Creates a new “safe” tag instance.

pub const fn number(num: u64) -> BlockId

Creates a new block number instance.

pub const fn hash(block_hash: FixedBytes<32>) -> BlockId

Create a new block hash instance.

pub const fn hash_canonical(block_hash: FixedBytes<32>) -> BlockId

Create a new block hash instance that requires the block to be canonical.