pub enum HttpServerRequest {
Http(IncomingHttpRequest),
WebSocketOpen {
path: String,
channel_id: u32,
source_socket_addr: Option<String>,
forwarded_for: Option<String>,
},
WebSocketPush {
channel_id: u32,
message_type: WsMessageType,
},
WebSocketClose(u32),
}Expand description
crate::Request received from the http-server:distro:sys service as a
result of either an HTTP or WebSocket binding, created via HttpServerAction.
Variants
Http(IncomingHttpRequest)
WebSocketOpen
Processes will receive this kind of request when a client connects to them.
If a process does not want this websocket open, they should issue a crate::Request
containing a HttpServerAction::WebSocketClose message and this channel ID.
Fields
WebSocketPush
Processes can both SEND and RECEIVE this kind of crate::Request
(send as HttpServerAction::WebSocketPush).
When received, will contain the message bytes as crate::LazyLoadBlob.
WebSocketClose(u32)
Receiving will indicate that the client closed the socket. Can be sent to close
from the server-side, as HttpServerAction::WebSocketClose.
Implementations
Sourceimpl HttpServerRequest
impl HttpServerRequest
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self>
pub fn from_bytes(bytes: &[u8]) -> Result<Self>
Parse a byte slice into an HttpServerRequest.
Sourcepub fn request(self) -> Option<IncomingHttpRequest>
pub fn request(self) -> Option<IncomingHttpRequest>
Filter the general-purpose HttpServerRequest, which contains HTTP requests
and WebSocket messages, into just the HTTP request. Consumes the original request
and returns None if the request was WebSocket-related.