pub struct Manifest {
pub items: Vec<(String, ManifestItem)>,
pub manifest_filename: String,
pub chain_id: String,
pub protocol_version: String,
}Expand description
The main manifest structure, listing all available log cache files. WIT does not support direct map types, so a list of key-value tuples is used.
Fields
items: Vec<(String, ManifestItem)>The key is the filename of the log cache.
manifest_filename: Stringchain_id: Stringprotocol_version: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Manifest
impl<'de> Deserialize<'de> for Manifest
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more