pub enum TimerAction {
Debug,
SetTimer(u64),
}Expand description
The Request::body() field for requests to timer:distro:sys, a runtime module
that allows processes to set timers with a duration specified in milliseconds.
The timer module is public, so no particular capabilities are required to use it.
Variants